================
eRepublik script
================


.. image:: https://img.shields.io/pypi/v/erepublik.svg
        :target: https://pypi.python.org/pypi/erepublik

.. image:: https://readthedocs.org/projects/erepublik/badge/?version=latest
        :target: https://erepublik.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python package for automated eRepublik playing


* Free software: GPLv3.0
* Documentation: https://erepublik.readthedocs.io/en/latest/
* Source code: https://github.com/eeriks/erepublik


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
